package com.dgtly.system.service.impl;

import java.util.List;
import com.dgtly.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.system.mapper.AlertUpvoteLogMapper;
import com.dgtly.system.domain.AlertUpvoteLog;
import com.dgtly.system.service.IAlertUpvoteLogService;
import com.dgtly.common.core.text.Convert;

/**
 * 弹框点赞日志Service业务层处理
 * 
 * @author dgtlc
 * @date 2024-12-24
 */
@Service
public class AlertUpvoteLogServiceImpl implements IAlertUpvoteLogService 
{
    @Autowired
    private AlertUpvoteLogMapper alertUpvoteLogMapper;

    /**
     * 查询弹框点赞日志
     * 
     * @param alertUpvoteId 弹框点赞日志ID
     * @return 弹框点赞日志
     */
    @Override
    public AlertUpvoteLog selectAlertUpvoteLogById(Long alertUpvoteId)
    {
        return alertUpvoteLogMapper.selectAlertUpvoteLogById(alertUpvoteId);
    }

    /**
     * 查询弹框点赞日志列表
     * 
     * @param alertUpvoteLog 弹框点赞日志
     * @return 弹框点赞日志
     */
    @Override
    public List<AlertUpvoteLog> selectAlertUpvoteLogList(AlertUpvoteLog alertUpvoteLog)
    {
        return alertUpvoteLogMapper.selectAlertUpvoteLogList(alertUpvoteLog);
    }

    /**
     * 新增弹框点赞日志
     * 
     * @param alertUpvoteLog 弹框点赞日志
     * @return 结果
     */
    @Override
    public int insertAlertUpvoteLog(AlertUpvoteLog alertUpvoteLog)
    {
        alertUpvoteLog.setCreateTime(DateUtils.getNowDate());
        return alertUpvoteLogMapper.insertAlertUpvoteLog(alertUpvoteLog);
    }

    /**
     * 修改弹框点赞日志
     * 
     * @param alertUpvoteLog 弹框点赞日志
     * @return 结果
     */
    @Override
    public int updateAlertUpvoteLog(AlertUpvoteLog alertUpvoteLog)
    {
        alertUpvoteLog.setUpdateTime(DateUtils.getNowDate());
        return alertUpvoteLogMapper.updateAlertUpvoteLog(alertUpvoteLog);
    }

    /**
     * 删除弹框点赞日志对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteAlertUpvoteLogByIds(String ids)
    {
        return alertUpvoteLogMapper.deleteAlertUpvoteLogByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除弹框点赞日志信息
     * 
     * @param alertUpvoteId 弹框点赞日志ID
     * @return 结果
     */
    @Override
    public int deleteAlertUpvoteLogById(Long alertUpvoteId)
    {
        return alertUpvoteLogMapper.deleteAlertUpvoteLogById(alertUpvoteId);
    }

    /**
     * @description: 根据用户ID、弹框ID查询是否有记录
     * @param userId 用户ID
     * @param alertId 弹框ID
     * @return com.dgtly.system.domain.AlertUpvoteLog
     * @author lc
     * @date 2024-12-25 11:12
     */
    @Override
    public AlertUpvoteLog selectUpvoteByUidAndAid(Long userId, Long alertId) {
        return alertUpvoteLogMapper.selectUpvoteByUidAndAid(userId, alertId);
    }
}
